@@ -15,8 +15,7 @@ use DBD::SQLite  1.25 ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.26_01';
-	$VERSION = eval $VERSION;
+	$VERSION = '1.29_01';
 }
 
 # Support for the 'prune' option
@@ -95,9 +94,9 @@ sub import {
 		my $dir = File::Basename::dirname($file);
 		unless ( -d $dir ) {
 			my @dirs = File::Path::mkpath( $dir, { verbose => 0 } );
-			push @PRUNE, @dirs if $params{prune};
+			$class->prune(@dirs) if $params{prune};
 		}
-		push @PRUNE, $file if $params{prune};
+		$class->prune($file) if $params{prune};
 	}
 	my $pkg      = $params{package};
 	my $readonly = $params{readonly};
@@ -261,6 +260,7 @@ END_PERL
 
 			# Discover the primary key
 			@{$table->{pk}}  = map($_->{name}, grep { $_->{pk} } @columns);
+			$table->{pks}    = scalar(@{$table->{pk}});
 
 			# What will be the class for this table
 			$table->{class}  = ucfirst lc $table->{name};
@@ -277,6 +277,7 @@ END_PERL
 				"insert into $table->{name}" .
 				"( $table->{sql}->{cols} )"  .
 				" values ( $table->{sql}->{vals} )";
+			$sql->{where_pk}    = join(' and ', map("$_ = ?", @{$table->{pk}}))
 		}
 
 		# Generate the foreign key metadata
@@ -344,17 +345,33 @@ sub iterate {
 
 END_PERL
 
+			# Add the primary key based single object loader
+			if ( $table->{pks} == 1 ) {
+				$code .= <<"END_PERL";
+sub load {
+	my \$class = shift;
+	my \$sql   = '$sql->{select} where $sql->{where_pk}';
+	my \$row   = $pkg->selectall_arrayref( \$sql, { Slice => {} }, \@_ );
+	unless ( \@\$row ) {
+		Carp::croak("$table->{class} with id '\$_[0]' does not exist");
+	}
+	bless( \$row->[0], '$table->{class}' );
+	return \$row->[0];
+}
+	
+END_PERL
+			}
+
 			# Generate the elements for tables with primary keys
 			if ( defined $table->{pk} and ! $readonly ) {
 				my $nattr = join "\n", map { "\t\t$_ => \$attr{$_}," } @names;
 				my $iattr = join "\n", map { "\t\t\$self->{$_},"       } @names;
 				my $fill_pk = scalar @{$table->{pk}} == 1 
-					    ? "\t\$self->{$table->{pk}->[0]} = \$dbh->func('last_insert_rowid') unless \$self->{$table->{pk}->[0]};"
-					    : q{};
+					? "\t\$self->{$table->{pk}->[0]} = \$dbh->func('last_insert_rowid') unless \$self->{$table->{pk}->[0]};"
+					: q{};
 				my $where_pk      = join(' and ', map("$_ = ?", @{$table->{pk}}));
-				my $where_pk_attr = join("\n", map("\t\t\$self->{$_},", @{$table->{pk}}));				
+				my $where_pk_attr = join("\n", map("\t\t\$self->{$_},", @{$table->{pk}}));
 				$code .= <<"END_PERL";
-
 sub new {
 	my \$class = shift;
 	my \%attr  = \@_;
@@ -453,6 +470,11 @@ sub dval {
 	return 1;
 }
 
+sub prune {
+	my $class = shift;
+	push @PRUNE, map { File::Spec->rel2abs($_) } @_;
+}
+
 1;
 
 __END__
